==> ali-reactjs-1.0.0.tgz: package/index.js <==
#!/usr/bin/env node 
var fs = require('fs');
var path = require('path');
var exec = require('child_process').exec; 
var chalk = require('chalk');

// console.log((process.env._));
// console.log(fs.readlinkSync(process.env._));
var sourcePath = path.join(path.dirname(process.env._) , path.dirname(fs.readlinkSync(process.env._))) + '/';

//console.log(sourcePath);

var help = function(){
    console.log('the reactjs user guide');
    console.log(chalk.green('reactjs : ') + 'show the help of reactjs');
    console.log(chalk.green('reactjs -h : ') + 'show the help of reactjs');
    console.log(chalk.green('reactjs -i <projectName> : ') + 'init a project named <projectName>');
    console.log(chalk.green('reactjs -p <pageName>: ') + 'create one page name <pageName>');
    console.log(chalk.green('reactjs -c <componentName>: ') + 'create one component name <componentName>');
    console.log(chalk.green('reactjs <componentName>: ') + 'create one component name <componentName>');
}

function copyFile(sourceFile , desFile , p , fullPath){
    var str = '';
    if(fullPath){
        str = fs.readFileSync(sourceFile).toString();
    }
    else{
        str = fs.readFileSync(sourcePath + sourceFile).toString();
    }
    
    var writerStream = fs.createWriteStream(desFile);
    for(var key in p){
        str = str.replace(new RegExp("{{"+key+"}}" , 'g') , p[key]);
    }
    writerStream.write(str.toString(),'UTF8');
    writerStream.end();
    //console.log("创建文件：" + desFile);
}




var initProject = function(param){
    fs.readdir('.' , function(err , files){
        if(err) {
            console.log(chalk.red.bold(err));
            return;
        } else {
            var flag = true;
            files.forEach(function(file){
                if('gulpfile.js,package.json.webpack.config.js,src'.indexOf(file) > -1){
                    flag = false;
                }
            });
            if(!flag){
                console.log('can not init \'' + param.name + '\' , ' + chalk.red.bold(' please be sure this is an empty directory') );
                return ;
            }
            copyFile('base/project/package.json' , './package.json' , {name : param.name});
            copyFile('base/project/gitignore' , './.gitignore' , {});
            copyFile('base/project/gulpfile.js' , './gulpfile.js' , {});
            copyFile('base/project/webpack.config.js' , './webpack.config.js' , {});
            fs.mkdirSync('src');
            fs.mkdirSync('src/pages');
            fs.mkdirSync('src/components');
            copyFile('base/page/common.less' , './src/pages/common.less' , {});
            var commond = 'cp -rf ' + sourcePath + 'base/project/utils' + ' ./src/';
            exec(commond);
            console.log( chalk.cyan('init \'' + param.name + '\' successed') );
        }
    });
}

var createPage = function(param){
    var path = process.env.PWD;
    if(fs.existsSync('src/pages/' + param.name + '.js')){
        return console.log('can not create the page \''+ param.name +'\' , because ' + chalk.red.bold('the page \''+ param.name +'\' has exised') );
    }

    if(fs.existsSync('src/pages')){
        copyFile( "base/page/base-page.htm" , './src/pages/' + param.name  + '.htm' , param);
        copyFile( "base/page/base-page.js" , './src/pages/' + param.name  + '.js' , param);
        copyFile( "base/page/base-page.less" , './src/pages/' + param.name  + '.less' , param);
        copyFile( "./webpack.config.js" , './webpack.config.js' , {
            hotDebugEntry : "{{hotDebugEntry}}\t\n\t\t'" + param.name + "' : ['webpack/hot/dev-server', './src/pages/" + param.name + ".js'] ," ,
            entry : "{{entry}}\t\n\t\t'"  + param.name + "' : ['./src/pages/"+param.name+".js'], "
        } , true);
        console.log( chalk.cyan('create \'' + param.name + '\' page successed') );
    }
    else {
        console.log('can not find the directory \'src/pages\' , please use the \'reactjs -p {name}\' code ' + chalk.red.bold(' in an react inited project') );
    }
}

var createComponent = function(param){
    if(fs.existsSync('src/components/' + param.path)){
        return console.error('can not create the component \''+ param.name +'\' , because ' + chalk.red.bold('the page \''+ param.name +'\' has exised') );
    }
    if(fs.existsSync('src/components')){
        fs.mkdirSync('src/components/' + param.path);
        copyFile("base/component/BaseComponent.js" , './src/components/' + param.path + '/' + param.name  + '.js' , param);
        copyFile("base/component/BaseComponent.less" , './src/components/' + param.path + '/' + param.name  + '.less' , param);
        copyFile("base/component/BaseComponent.mock.js" , './src/components/' + param.path + '/' + param.name  + '.mock.js' , param);
        console.log( chalk.cyan('create \'' + param.name + '\' component successed') );
    }
    else {
        console.log('can not find the directory \'src/components\' , please use the \'reactjs -p {name}\' code ' + chalk.red.bold(' in an react inited project') );
    }
}


var formatParam = function(obj){
    var param = {type : '-h'};
    var error = false;
    if(obj.length == 1){
        param = obj[0].indexOf('-') == 0 ? {type : obj[0]} : {type : '-c' , name : obj[0]};
    }
    else if(obj.length == 2){
        param = obj[0].indexOf('-') == 0 ? {type : obj[0] , name : obj[1]} : {type : obj[1] , name : obj[0]};
    }
    if('-h-i-p-c'.indexOf(param.type) == -1){
        error = true;
    }  
    if('-i-p-c'.indexOf(param.type) != -1 && !param.name){
        error = true;
    }
    
    //处理名字
    if(param.type == '-c'){
        var name = param.name;
        var path = name.replace(/[A-Z]/g , function(c , i){
            if(i == 0){
                return c.toLocaleLowerCase();
            }
            return '-' + c.toLocaleLowerCase();
        });
        name =('-' +  name).replace(/\-[a-z,A-Z]/g , function(c , i){
            return  c.substring(1).toLocaleUpperCase();
        });
        param.path = path;
        param.name = name;
    }
    if(param.type == '-i' || param.type == '-p'){
        param.name = param.name.replace(/[A-Z]/g , function(c , i){
            if(i == 0){
                return c.toLocaleLowerCase();
            }
            return '-' + c.toLocaleLowerCase();
        });
    }
    if(error){
        console.log(chalk.red.bold('parameter error .') + ' Please use the reactjs -h to view how to use the command');
        param = false;
    }
    return param;
}


var run = function(obj){
    var param = formatParam(obj);
    if(param.type == '-i'){
        initProject(param);
    }
    if(param.type == '-p'){
        createPage(param);
    }
    if(param.type == '-c'){
        createComponent(param);
    }
    if(param.type == '-h'){
        help();
    }
}

run(process.argv.slice(2 , 4));



// console.log(chalk.black('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.red('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.green('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.yellow('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.blue('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.magenta('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.cyan('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.white('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.gray('test a color!haha!!! do you think this is beautiful'));

==> ali-reactjs-1.1.2.tgz: package/index.js <==
#!/usr/bin/env node 
var fs = require('fs');
var path = require('path');
var exec = require('child_process').exec; 
var chalk = require('chalk');
var request = require('request');
var crypto = require('crypto');
var iconv = require('iconv-lite');

// console.log((process.env._));
// console.log(fs.readlinkSync(process.env._));
var sourcePath = path.join(path.dirname(process.env._) , path.dirname(fs.readlinkSync(process.env._))) + '/';

//console.log(sourcePath);

var help = function(){
    console.log('the reactjs user guide');
    console.log(chalk.green('reactjs : ') + 'show the help of reactjs');
    console.log(chalk.green('reactjs -h : ') + 'show the help of reactjs');
    console.log(chalk.green('reactjs -i <projectName> : ') + 'init a project named <projectName>');
    console.log(chalk.green('reactjs -p <pageName>: ') + 'create one page name <pageName>');
    console.log(chalk.green('reactjs -c <componentName>: ') + 'create one component name <componentName>');
    console.log(chalk.green('reactjs <componentName>: ') + 'create one component name <componentName>');
}

function copyFile(sourceFile , desFile , p , fullPath){
    var str = '';
    if(fullPath){
        str = fs.readFileSync(sourceFile).toString();
    }
    else{
        str = fs.readFileSync(sourcePath + sourceFile).toString();
    }
    
    var writerStream = fs.createWriteStream(desFile);
    for(var key in p){
        str = str.replace(new RegExp("{{"+key+"}}" , 'g') , p[key]);
    }
    writerStream.write(str.toString(),'UTF8');
    writerStream.end();
    //console.log("创建文件：" + desFile);
}




var initProject = function(param){
    fs.readdir('.' , function(err , files){
        if(err) {
            console.log(chalk.red.bold(err));
            return;
        } else {
            var flag = true;
            files.forEach(function(file){
                if('gulpfile.js,package.json.webpack.config.js,src'.indexOf(file) > -1){
                    flag = false;
                }
            });
            if(!flag){
                console.log('can not init \'' + param.name + '\' , ' + chalk.red.bold(' please be sure this is an empty directory') );
                return ;
            }
            copyFile('base/project/package.json' , './package.json' , {name : param.name});
            copyFile('base/project/gitignore' , './.gitignore' , {});
            copyFile('base/project/gulpfile.js' , './gulpfile.js' , {});
            copyFile('base/project/webpack.config.js' , './webpack.config.js' , {});
            fs.mkdirSync('src');
            fs.mkdirSync('src/pages');
            fs.mkdirSync('src/components');
            copyFile('base/page/common.less' , './src/pages/common.less' , {});
            exec('cp -rf ' + sourcePath + 'base/project/utils' + ' ./src/');
            exec('cp -rf ' + sourcePath + 'src/components/' + ' ./src/components');
            exec('cp -rf ' + sourcePath + 'src/pages/' + ' ./src/pages');
            console.log( chalk.cyan('init \'' + param.name + '\' successed') );
        }
    });
}  

var createPage = function(param){
    var path = process.env.PWD;
    if(fs.existsSync('src/pages/' + param.name + '.js')){
        return console.log('can not create the page \''+ param.name +'\' , because ' + chalk.red.bold('the page \''+ param.name +'\' has exised') );
    }

    if(fs.existsSync('src/pages')){
        copyFile( "base/page/base-page.htm" , './src/pages/' + param.name  + '.htm' , param);
        copyFile( "base/page/base-page.js" , './src/pages/' + param.name  + '.js' , param);
        copyFile( "base/page/base-page.less" , './src/pages/' + param.name  + '.less' , param);
        copyFile( "./webpack.config.js" , './webpack.config.js' , {
            hotDebugEntry : "{{hotDebugEntry}}\t\n\t\t'" + param.name + "' : ['webpack/hot/dev-server', './src/pages/" + param.name + ".js'] ," ,
            entry : "{{entry}}\t\n\t\t'"  + param.name + "' : ['./src/pages/"+param.name+".js'], "
        } , true);
        console.log( chalk.cyan('create \'' + param.name + '\' page successed') );
    }
    else {
        console.log('can not find the directory \'src/pages\' , please use the \'reactjs -p {name}\' code ' + chalk.red.bold(' in an react inited project') );
    }
}

var createComponent = function(param){
    if(fs.existsSync('src/components/' + param.path)){
        return console.error('can not create the component \''+ param.name +'\' , because ' + chalk.red.bold('the page \''+ param.name +'\' has exised') );
    }
    if(fs.existsSync('src/components')){
        fs.mkdirSync('src/components/' + param.path);
        copyFile("base/component/BaseComponent.js" , './src/components/' + param.path + '/' + param.name  + '.js' , param);
        copyFile("base/component/BaseComponent.less" , './src/components/' + param.path + '/' + param.name  + '.less' , param);
        copyFile("base/component/BaseComponent.mock.js" , './src/components/' + param.path + '/' + param.name  + '.mock.js' , param);
        console.log( chalk.cyan('create \'' + param.name + '\' component successed') );
    }
    else {
        console.log('can not find the directory \'src/components\' , please use the \'reactjs -p {name}\' code ' + chalk.red.bold(' in an react inited project') );
    }
}

var post = function(param){
    console.log(param);
    var json =  JSON.parse(fs.readFileSync('./awp.js', {encoding:'utf8'}));
    console.log(json);
    var uri = json.uri;
    json.fileData = fs.createReadStream(json.file);
    console.log('fileData >>>>>>');
    console.log(json.fileData);
    json.t = new Date().getTime();
    request.post({
        headers: {
            'X-Forwarded-For': '10.232.135.52' // 通用跳板机
        },
        url: uri,
        //form: param,
        formData: json,
        //encoding: 'utf8',
        json: true
    }, function (err, response, ret) {
        console.log(err);
        console.log(response);
        console.log(ret);
        
    });
}

var getIPAdress = function(){  
    var interfaces = require('os').networkInterfaces();  
    for(var devName in interfaces){  
          var iface = interfaces[devName];  
          for(var i=0;i<iface.length;i++){  
               var alias = iface[i];  
               if(alias.family === 'IPv4' && alias.address !== '127.0.0.1' && !alias.internal){  
                     return alias.address;  
               }  
          }  
    }  
}  

var changeIPAddress = function(){
    var ip = getIPAdress();
    var list = [];
    if(fs.existsSync('./gulpfile.js')){
        list.push('./gulpfile.js');
    }
    // var str = fs.readFileSync('./gulpfile.js').toString();
    var reg = /[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+/g;
    // var writerStream = fs.createWriteStream('./gulpfile.js');
    // writerStream.write(str.replace(reg , ip).toString() ,'UTF8');
    // writerStream.end();
    if(fs.existsSync('./src/pages')){
        fs.readdir('./src/pages/' , function(err, files) { 
            //console.log(JSON.stringify(files));
            for(var i=0; i<files.length; i++){
                var file = files[i];
                if(file.indexOf('.htm') > -1){
                    list.push('./src/pages/' + file);
                }
            }
            for(var i=0; i<list.length; i++){
                var str = fs.readFileSync(list[i]).toString();
                var writerStream = fs.createWriteStream(list[i]);
                writerStream.write(str.replace(reg , ip).toString() ,'UTF8');
                writerStream.end();
            }
        });
    }
    console.log( chalk.cyan('all the IP has been changed to ' + ip));
    
}


var formatParam = function(obj){
    var param = {type : '-h'};
    var error = false;
    if(obj.length == 1){
        param = obj[0].indexOf('-') == 0 ? {type : obj[0]} : {type : '-c' , name : obj[0]};
    }
    else if(obj.length == 2){
        param = obj[0].indexOf('-') == 0 ? {type : obj[0] , name : obj[1]} : {type : obj[1] , name : obj[0]};
    }
    if('-h-ip-i-p-c-a'.indexOf(param.type) == -1){
        error = true;
    }  
    if('-i-p-c-a'.indexOf(param.type) != -1 && !param.name){
        error = true;
    }
    
    //处理名字
    if(param.type == '-c'){
        var name = param.name;
        var path = name.replace(/[A-Z]/g , function(c , i){
            if(i == 0){
                return c.toLocaleLowerCase();
            }
            return '-' + c.toLocaleLowerCase();
        });
        name =('-' +  name).replace(/\-[a-z,A-Z]/g , function(c , i){
            return  c.substring(1).toLocaleUpperCase();
        });
        param.path = path;
        param.name = name;
    }
    if(param.type == '-i' || param.type == '-p' || param.type == '-a'){
        param.name = param.name.replace(/[A-Z]/g , function(c , i){
            if(i == 0){
                return c.toLocaleLowerCase();
            }
            return '-' + c.toLocaleLowerCase();
        });
    }
    if(error){
        console.log(chalk.red.bold('parameter error .') + ' Please use the reactjs -h to view how to use the command');
        param = false;
    }
    return param;
}


var run = function(obj){
    var param = formatParam(obj);
    if(param.type == '-i'){
        initProject(param);
    }
    if(param.type == '-p'){
        createPage(param);
    }
    if(param.type == '-c'){
        createComponent(param);
    }
    if(param.type == '-a'){
        post(param);
    }
    if(param.type == '-h'){
        help();
    }
    if(param.type == '-ip'){
        changeIPAddress();
    }

}

run(process.argv.slice(2 , 4));



// console.log(chalk.black('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.red('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.green('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.yellow('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.blue('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.magenta('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.cyan('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.white('test a color!haha!!! do you think this is beautiful'));
// console.log(chalk.gray('test a color!haha!!! do you think this is beautiful'));
